"""
Generate images of "gauges" for production run

Inputs:

production dirs: dictionary of production directories with a
                 association to that simulation run, eg high tide,
                 low tide and MSL.
                    
Outputs:

* figures used for report stored in the report_figure directory

"""
from os import getcwd, sep, altsep, mkdir, access, F_OK
import project
from anuga.abstract_2d_finite_volumes.util import sww2timeseries

production_dirs = {'20080619_115643_run_trial_0.6_exmouth_kvanputt': ''}

is_parallel = False

if is_parallel is True:
    no_nodes = 4
    
if is_parallel is False:
    
    swwfiles = {}    
    for label_id in production_dirs.keys():
        
        file_loc = project.output_dir + label_id + sep
        swwfile = file_loc + project.scenario_name + '.sww'
        swwfiles[swwfile] = label_id
            
        texname, elev_output = sww2timeseries(swwfiles,
                                              project.gauges_dir_name,
                                              production_dirs,
                                              report = False,
                                              plot_quantity = ['stage', 'speed', 'depth'],
                                              generate_fig = False,
                                              surface = False,
                                              time_min = None,
                                              time_max = None,
                                              time_unit = 'mins',
                                              title_on = False,
                                              use_cache = True,
                                              verbose = True)

if is_parallel is True:                                      

    for count in range(no_nodes):
        swwfiles = {} 
        for label_id in production_dirs.keys():

            file_loc = project.output_dir + label_id + sep
            extra = '_P%i_%i' %(count,no_nodes)
            swwfile = file_loc + project.scenario_name + extra + '.sww'
            swwfiles[swwfile] = label_id

            texname, elev_output = sww2timeseries(swwfiles,
                                                  project.gauges_dir_name,
                                                  production_dirs,
                                                  report = False,
                                                  plot_quantity = ['stage', 'speed'],
                                                  generate_fig = False,
                                                  surface = False,
                                                  time_min = None,
                                                  time_max = None,
                                                  time_unit = 'mins',
                                                  title_on = False,
                                                  use_cache = True,
                                                  verbose = True)
                                      
